#
# Copyright (c) 2010 Canonical
#
# Written by Gustavo Niemeyer <gustavo@niemeyer.net>
#
# This file is part of the Xpresser GUI automation library.
#
# Xpresser is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3,
# as published by the Free Software Foundation.
#
# Xpresser is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
import pyatspi
import SimpleCV
from xpresser.image import Image
from tempfile import NamedTemporaryFile
from gi.repository import Gdk


def click(x, y):
    pyatspi.Registry.generateMouseEvent(x, y, pyatspi.MOUSE_B1C)

def right_click(x, y):
    pyatspi.Registry.generateMouseEvent(x, y, pyatspi.MOUSE_B3C)

def double_click(x, y):
    pyatspi.Registry.generateMouseEvent(x, y, pyatspi.MOUSE_B1D)

def hover(x, y):
    pyatspi.Registry.generateMouseEvent(x, y, pyatspi.MOUSE_ABS)

def type(string):
    for char in string:
        keyval = Gdk.unicode_to_keyval(ord(char))
        pyatspi.Registry.generateKeyboardEvent(keyval, None, pyatspi.KEY_SYM)

def take_screenshot():
    window = Gdk.get_default_root_window()
    surface = Gdk.cairo_create(window).get_target()
    with NamedTemporaryFile(prefix='xpresser_', suffix='.png') as f:
        surface.write_to_png(f.name)
        opencv_image = SimpleCV.Image(f.name)
    return Image("screenshot", array=opencv_image,
                 width=opencv_image.width, height=opencv_image.height)
